@@ -12,11 +12,11 @@ terraria_app_id = 105600
 steam = Steam("32695860B33BD953838E0888B4738021")
 
 # arguments: app_id
-test = steam.apps.get_app_details(292030, "UA")
+# test = steam.apps.get_app_details(292030, filters="price_overview")
 # user = steam.apps.get_user_achievements(76561198040366189, 105600)
 # test = steam.users.search_user("regulartetragon")
 
-
+test = steam.apps.search_games("dune", fetch_discounts=True)
 # user = steam.users.get_user_details("1")
 print(test)
 # s = 'p\u0443\u0431'
